@@ -2,12 +2,14 @@ import logging
 
 import numpy as np
 import scipy.linalg as sla
-from scipy.stats import norm
 
-from .bvn_cdf import bvn_cdf
+# noinspection PyUnresolvedReferences
+from .bvn_cdf import bvn_cdf, s_bvn_cdf
 
 __all__ = ['toeplitz_solve', 's_toeplitz_solve',
-           'bvn_cdf', 's_bvn_cdf']
+           'bvn_cdf', 's_bvn_cdf',
+           'expm', 's_expm',
+           'logm', 's_logm']
 
 log = logging.getLogger(__name__)
 
@@ -82,17 +84,18 @@ def s_toeplitz_solve(s_y, y, a, b, c):
     return s_a, s_b, s_c
 
 
-def s_bvn_cdf(s_y, y, a, b, c):
-    q = np.sqrt(1 - c ** 2)
+def expm(a):
+    return sla.expm(a)
 
-    # Compute the densities.
-    pdfs = 1 / (2 * np.pi * q) * \
-           np.exp(-(a ** 2 - 2 * c * a * b + b ** 2) /
-                  (2 * (1 - c ** 2)))
 
-    # Compute sensitivities.
-    s_a = s_y * norm.pdf(a) * norm.cdf(b, c * a, q)
-    s_b = s_y * norm.pdf(b) * norm.cdf(a, c * b, q)
-    s_c = s_y * pdfs
+def s_expm(s_y, y, a):
+    return sla.expm_frechet(a, s_y.T, compute_expm=False).T
 
-    return s_a, s_b, s_c
+
+def logm(a):
+    return sla.logm(a)
+
+
+def s_logm(a):  # pragma: no cover
+    raise NotImplementedError('The derivative for the matrix logarithm is '
+                              'current not implemented.')
